==> nextcloud-13.0.2.tar.bz2: nextcloud/apps/dav/l10n/fi.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalenteri",
    "Todos" : "Tehtävät",
    "Personal" : "Henkilökohtainen",
    "{actor} created calendar {calendar}" : "{actor} loi kalenterin {calendar}",
    "You created calendar {calendar}" : "Loit kalenterin {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} poisti kalenterin {calendar}",
    "You deleted calendar {calendar}" : "Poistit kalenterin {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} päivitti kalenterin {calendar}",
    "You updated calendar {calendar}" : "Päivitit kalenterin {calendar}",
    "You shared calendar {calendar} as public link" : "Jaoit kalenterin {calendar} julkisena linkkinä",
    "You removed public link for calendar {calendar}" : "Poistit julkisen linkin kalenterilta {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} jakoi kalenterin {calendar} kanssasi",
    "You shared calendar {calendar} with {user}" : "Jaoit kalenterin {calendar} käyttäjälle {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} jakoi kalenterin {calendar} käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} lopetti kalenterin {calendar} jakamisen kanssasi",
    "You unshared calendar {calendar} from {user}" : "Lopetit kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} lopetti kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} lopetti kalenterin {calendar} jakamisen itselleen",
    "You shared calendar {calendar} with group {group}" : "Jaoit kalenterin {calendar} ryhmälle {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} jakoi kalenterin {calendar} ryhmälle {group}",
    "You unshared calendar {calendar} from group {group}" : "Lopetit kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} lopetti kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} loi tapahtuman {event} kalenteriin {calendar}",
    "You created event {event} in calendar {calendar}" : "Loit tapahtuman {event} kalenteriin {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} poisti tapahtuman {event} kalenterista {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Poistit tapahtuman {event} kalenterista {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} päivitti tapahtuman {event} kalenteriin {calendar}",
    "You updated event {event} in calendar {calendar}" : "Päivitit tapahtuman {event} kalenteriin {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} loi tehtävän {todo} listaan {calendar}",
    "You created todo {todo} in list {calendar}" : "Loit tehtävän {todo} listaan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} poisti tehtävän {todo} listasta {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Poistit tehtävän {todo} listasta {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} päivitti tehtävän {todo} listassa {calendar}",
    "You updated todo {todo} in list {calendar}" : "Päivitit tehtävän {todo} listassa {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} suoritti tehtävän {todo} listasta {calendar}",
    "You solved todo {todo} in list {calendar}" : "Suoritit tehtävän {todo} listasta {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} avasi uudelleen tehtävän {todo} listassa {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Avasit uudelleen tehtävän {todo} listassa {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalenteria</strong> on muokattu",
    "A calendar <strong>event</strong> was modified" : "Kalenterin <strong>tapahtumaa</strong> on muokattu",
    "A calendar <strong>todo</strong> was modified" : "Kalenterin <strong>tehtävää</strong> on muokattu",
    "Contact birthdays" : "Yhteystietojen syntymäpäivät",
    "Invitation canceled" : "Kutsu peruttu",
    "Hello %s," : "Hei %s",
    "The meeting »%s« with %s was canceled." : "Tapaaminen »%s« henkilön %s kanssa peruttiin.",
    "Invitation updated" : "Kutsu päivitetty",
    "The meeting »%s« with %s was updated." : "Tapaaminen »%s« henkilön %s kanssa päivitettiin.",
    "%s invited you to »%s«" : "%s kutsui sinut »%s«",
    "When:" : "Milloin:",
    "Where:" : "Missä:",
    "Description:" : "Kuvaus:",
    "Link:" : "Linkki:",
    "Contacts" : "Yhteystiedot",
    "WebDAV" : "WebDAV",
    "Technical details" : "Tekniset yksityiskohdat",
    "Remote Address: %s" : "Etäosoite: %s",
    "Request ID: %s" : "Pyynnön tunniste: %s",
    "CalDAV server" : "CalDAV-palvelin",
    "Send invitations to attendees" : "Lähetä kutsut osallistujille",
    "Please make sure to properly set up the email settings above." : "Varmista, että määrität sähköpostiasetukset oikein yläpuolelle. ",
    "Automatically generate a birthday calendar" : "Luo syntymäpäiväkalenteri automaattisesti",
    "Birthday calendars will be generated by a background job." : "Syntymäpäiväkalenterit luodaan taustatyön toimesta.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Sen vuoksi ne eivät ole välittömästi saatavilla käyttöönoton jälkeen, vaan ne tulevat näkyviin pienellä viiveellä."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.14.tar.bz2: nextcloud/apps/dav/l10n/fi.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalenteri",
    "Todos" : "Tehtävät",
    "Personal" : "Henkilökohtainen",
    "{actor} created calendar {calendar}" : "{actor} loi kalenterin {calendar}",
    "You created calendar {calendar}" : "Loit kalenterin {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} poisti kalenterin {calendar}",
    "You deleted calendar {calendar}" : "Poistit kalenterin {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} päivitti kalenterin {calendar}",
    "You updated calendar {calendar}" : "Päivitit kalenterin {calendar}",
    "You shared calendar {calendar} as public link" : "Jaoit kalenterin {calendar} julkisena linkkinä",
    "You removed public link for calendar {calendar}" : "Poistit julkisen linkin kalenterilta {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} jakoi kalenterin {calendar} kanssasi",
    "You shared calendar {calendar} with {user}" : "Jaoit kalenterin {calendar} käyttäjälle {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} jakoi kalenterin {calendar} käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} lopetti kalenterin {calendar} jakamisen kanssasi",
    "You unshared calendar {calendar} from {user}" : "Lopetit kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} lopetti kalenterin {calendar} jakamisen käyttäjälle {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} lopetti kalenterin {calendar} jakamisen itselleen",
    "You shared calendar {calendar} with group {group}" : "Jaoit kalenterin {calendar} ryhmälle {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} jakoi kalenterin {calendar} ryhmälle {group}",
    "You unshared calendar {calendar} from group {group}" : "Lopetit kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} lopetti kalenterin {calendar} jakamisen ryhmälle {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} loi tapahtuman {event} kalenteriin {calendar}",
    "You created event {event} in calendar {calendar}" : "Loit tapahtuman {event} kalenteriin {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} poisti tapahtuman {event} kalenterista {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Poistit tapahtuman {event} kalenterista {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} päivitti tapahtuman {event} kalenteriin {calendar}",
    "You updated event {event} in calendar {calendar}" : "Päivitit tapahtuman {event} kalenteriin {calendar}",
    "Busy" : "Varattu",
    "{actor} created todo {todo} in list {calendar}" : "{actor} loi tehtävän {todo} listaan {calendar}",
    "You created todo {todo} in list {calendar}" : "Loit tehtävän {todo} listaan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} poisti tehtävän {todo} listasta {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Poistit tehtävän {todo} listasta {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} päivitti tehtävän {todo} listassa {calendar}",
    "You updated todo {todo} in list {calendar}" : "Päivitit tehtävän {todo} listassa {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} suoritti tehtävän {todo} listasta {calendar}",
    "You solved todo {todo} in list {calendar}" : "Suoritit tehtävän {todo} listasta {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} avasi uudelleen tehtävän {todo} listassa {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Avasit uudelleen tehtävän {todo} listassa {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalenteria</strong> on muokattu",
    "A calendar <strong>event</strong> was modified" : "Kalenterin <strong>tapahtumaa</strong> on muokattu",
    "A calendar <strong>todo</strong> was modified" : "Kalenterin <strong>tehtävää</strong> on muokattu",
    "Contact birthdays" : "Yhteystietojen syntymäpäivät",
    "Calendar:" : "Kalenteri:",
    "Date:" : "Päiväys:",
    "Where:" : "Missä:",
    "Description:" : "Kuvaus:",
    "Untitled event" : "Nimetön tapahtuma",
    "_%n year_::_%n years_" : ["%n vuosi","%n vuotta"],
    "_%n month_::_%n months_" : ["%n kuukausi","%n kuukautta"],
    "_%n day_::_%n days_" : ["%n päivä","%n päivää"],
    "_%n hour_::_%n hours_" : ["%n tunti","%n tuntia"],
    "_%n minute_::_%n minutes_" : ["%n minuutti","%n minuuttia"],
    "%s (%s ago)" : "%s (%s sitten)",
    "Calendar: %s" : "Kalenteri: %s",
    "Date: %s" : "Päiväys: %s",
    "Description: %s" : "Kuvaus: %s",
    "Where: %s" : "Missä: %s",
    "Invitation canceled" : "Kutsu peruttu",
    "Hello %s," : "Hei %s",
    "Invitation updated" : "Kutsu päivitetty",
    "When:" : "Milloin:",
    "Link:" : "Linkki:",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "More options …" : "Lisää valintoja…",
    "Contacts" : "Yhteystiedot",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s tulee asettaa käyttämään HTTPS-yhteyttä, jotta CalDAVia ja CardDAVia voi käyttää iOSilla tai macOS:llä.",
    "Configures a CalDAV account" : "Määrittää CalDAV-tilin",
    "Configures a CardDAV account" : "Määrittää CardDAV-tilin",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-päätepiste",
    "Technical details" : "Tekniset yksityiskohdat",
    "Remote Address: %s" : "Etäosoite: %s",
    "Request ID: %s" : "Pyynnön tunniste: %s",
    "There was an error updating your attendance status." : "Osallistumisesi tilaa päivittäessä tapahtui virhe.",
    "Please contact the organizer directly." : "Ota yhteys suoraan järjestäjään.",
    "Are you accepting the invitation?" : "Hyväksytkö kutsun?",
    "Tentative" : "Alustava",
    "Save" : "Tallenna",
    "Your attendance was updated successfully." : "Osallistumisesi päivitettiin onnistuneesti.",
    "Calendar server" : "Kalenteripalvelin",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Asenna myös {calendarappstoreopen}kalenterisovellus{linkclose}, tai {calendardocopen}yhdistä tietokoneesi ja mobiililaitteesi synkronointiyhteyteen ↗{linkclose}.",
    "Send invitations to attendees" : "Lähetä kutsut osallistujille",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Varmista että määrität {emailopen}sähköpostipalvelimen{linkclose} asetukset oikein.",
    "Automatically generate a birthday calendar" : "Luo syntymäpäiväkalenteri automaattisesti",
    "Birthday calendars will be generated by a background job." : "Syntymäpäiväkalenterit luodaan taustatyön toimesta.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Sen vuoksi ne eivät ole välittömästi saatavilla käyttöönoton jälkeen, vaan ne tulevat näkyviin pienellä viiveellä.",
    "Send notifications for events" : "Lähetä ilmoitukset tapahtumista",
    "Please make sure to properly set up the email settings above." : "Varmista, että määrität sähköpostiasetukset oikein yläpuolelle. "
},
"nplurals=2; plural=(n != 1);");
